Recording good quality signals
======================================

.. important::
   Would like to add something or make a correction? Join us by contributing (`see this tutorial <https://neuropsychology.github.io/NeuroKit/resources/contributing.html>`_).

Here some useful resources to help you collect good quality signals. Remember, cleaning and processing can only get you this far, and having good signals from the start is the first step to a good analysis.

Recording
------------

- `Electrocardiogram (ECG) electrodes placement <https://www.youtube.com/watch?v=g5-39qux0Sc&feature=emb_title>`_
- `Facial EMG electrodes placement <https://www.youtube.com/watch?v=iDzcGWIGfVQ&feature=emb_title>`_
- `RSP belt placement <https://www.youtube.com/watch?v=eDIJ7AiKu8s&feature=emb_title>`_
- `Best Practices for Collecting Physiological Data <https://phys2bids.readthedocs.io/en/latest/bestpractice.html>`_

Signal quality
------------------

- `Improving Data Quality of ECG <https://support.mindwaretech.com/2017/12/improving-data-quality-ecg/>`_
- `Improving Data Quality of EDA <https://support.mindwaretech.com/2017/12/improving-data-quality-eda/>`_

Artifacts and Anomalies
-------------------------

- `Identifying and Handling Cardiac Arrhythmia <https://support.mindwaretech.com/2016/10/all-about-ecg-part-5-identifying-and-handling-cardiac-arrhythmia/>`_


